#
# spec file for package ghc-path
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name path
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.9.2
Release:        bp154.1.15
Summary:        Support for well-typed paths
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-text-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-genvalidity-devel
BuildRequires:  ghc-genvalidity-hspec-devel
BuildRequires:  ghc-genvalidity-property-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-validity-devel
%endif

%description
Support for well-typed paths.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG README.md

%changelog
* Mon Dec 27 2021 Peter Simons <psimons@suse.com>
- Update path to version 0.9.2.
  0.9.2
  * Data instances for Rel, Abs, File, and Dir.
  * Bump hashable upper bound to <1.5.
  0.9.1
  * Support for genvalidity >=1.0.0.0
  * `mapSomeBase` and `prjSomeBase` for modifying or projecting SomeBase.
* Sat Jun 19 2021 psimons@suse.com
- Update path to version 0.9.0.
  0.9.0
  * Fix inconsistencies on different platforms: [#166](https://github.com/commercialhaskell/path/issues/166)
  * `replaceProperPrefix`
  * Make it possible to use windows paths on posix and vice versa
* Fri Mar 12 2021 psimons@suse.com
- Update path to version 0.8.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Aug 21 2020 psimons@suse.com
- Update path to version 0.8.0.
  0.8.0
  * Rerelease of 0.7.1 with better version number
  0.7.1:
  * Test with GHC 8.8.2, 8.8.3, 8.10.1.
  * Export SomeBase constructor.
  * Fix Lift severe Lift instance bug
* Mon Dec 30 2019 psimons@suse.com
- Update path to version 0.7.0.
  0.7.0:
  * BREAKING CHANGE: "fileExtension" now throws an exception if the file has no
  extension. You can use the result as a "Maybe" in pure
  code or handle the exception appropriately in any other monad.
  * Old extension operations "addFileExtension" and "setFileExtension" have
  been deprecated and replaced by "addExtension" and "replaceExtension"
  respectively with new behavior.
  ADAPTING YOUR CODE TO THIS CHANGE:
  * Code that sets an extension not starting with a "." e.g.  "foo", must
  be changed such that it starts with a "." i.e. ".foo".
  * Code that sets multiple extensions in one go e.g. ".tar.gz" must be
  changed to set them one at a time instead i.e. add ".tar" first and
  then add ".gz".
  * Code that sets an extension starting with multiple dots e.g.
  "..foo" must be changed such as to make the extra dots part of the
  file name instead.
  Details:
  The new operations "addExtension" and "replaceExtension" accept only "valid"
  extension forms which is exactly the same as what "fileExtension" returns.
  A valid extension starts with a @.@ followed by one or more characters
  not including @.@ followed by zero or more @.@s in trailing position.
  This change allows extension operations to be principled following
  these laws:
  * flip addExtension file >=> fileExtension == return
  * (fileExtension >=> flip replaceExtension file) file == return file
  * Add splitExtension operation such that:
  * uncurry addExtension . swap >=> splitExtension == return
  * splitExtension >=> uncurry addExtension . swap == return
  * fileExtension == (fmap snd) . splitExtension@
  * Add 'Path.Posix' and 'Path.Windows' modules for manipulating
  Windows or Posix style paths independently of the current platform.
  * Add 'Lift' instance for 'Path'.
  * `Path.Windows` normalizes path separators throughout path,
  including immediately following drive letter.
  * `Path.Windows` handles UNC (`\\host\share\`) and Unicode (`\\?\C:\`) path
  without breaking the double-separator prefix.
  * Remove support for old GHC version. The oldest supported version
  is 8.2.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update path to version 0.6.1 revision 1.
  * Add 'addFileExtension' function and its operator form: (<.>).
  * Derive 'Eq' instance for 'PathException'.
  * Deprecate PathParseException and rename it to PathException
  * Allow 'parent' to work on relative paths as well
  * Deprecate isParentOf and stripDir and rename them to isProperPrefixOf and
    stripProperPrefix respectively.
  * Allow "." as a valid relative dir path with the following rules:
  * "./" </> "./" = "./"
  * "./" </> "x/" = "x/"
  * "x/" </> "./" = "x/"
  * dirname "x" = "./"
  * dirname "/" = "./"
  * dirname "./" = "./"
  * Make dirname return "." instead of "/" (fixes #18).
  * Remove the 'validity' flag.
  * Add synonym for setFileExtension in the form of an operator: (-<.>).
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Mar 27 2017 psimons@suse.com
- Update to version 0.5.13 with cabal2obs.
* Wed Mar 22 2017 psimons@suse.com
- Update to version 0.5.12 revision 2 with cabal2obs.
* Thu Mar  2 2017 psimons@suse.com
- Update to version 0.5.12 revision 1 with cabal2obs.
* Sun Feb  5 2017 psimons@suse.com
- Update to version 0.5.12 with cabal2obs.
* Fri Dec 16 2016 psimons@suse.com
- Update to version 0.5.11 revision 1 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.5.9 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.5.8 revision 0 with cabal2obs.
* Fri Jun 17 2016 mimi.vx@gmail.com
- update to 0.5.8
  * Add Aeson instances.
* Tue Mar  8 2016 mimi.vx@gmail.com
- update to 0.5.7
  * Fix haddock problem.
  * Reject only .. and .
  * Use filepath's isValid function for additional sanity checks
  * Disable parsing of path consisting only of "."
  * Add NFData instance for Path
  * Some typo/docs improvements
  * Add standard headers to modules
* Sun Nov 29 2015 mimi.vx@gmail.com
- update to 0.5.3
  * Added conversion functions.
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
